<?php
// Настройки сайта
define('FILE_CONFIG', __DIR__."/system.ini");
$sys = parse_ini_file(FILE_CONFIG, true);
// Отладка
ini_set('error_reporting', $sys['modules']['debug'] ? E_ALL : 0);
ini_set('display_errors', $sys['modules']['debug'] ? 1 : 0);
ini_set('display_startup_errors', $sys['modules']['debug'] ? 1 : 0);
// Настройки highlight
ini_set('highlight.keyword', $sys['system']['hl-keyword']);
ini_set('highlight.comment', $sys['system']['hl-comment']);
ini_set('highlight.string', $sys['system']['hl-string']);
ini_set('highlight.default', $sys['system']['hl-default']);
ini_set('highlight.html', $sys['system']['hl-html']);
// Подключение к БД
try {
    $connect = new PDO('mysql:host=' . $sys['db']['db_host'] . ';dbname=' . $sys['db']['db_name'] . ';charset=utf8', $sys['db']['db_user'], $sys['db']['db_pass']);
} catch (PDOException $e) {
    exit('Подключение не удалось: ' . $e->getMessage());
}
// Функции для работы с файлами
require_once(__DIR__."/file_function.php");
// Фильтр данных
require_once(__DIR__."/data_filter.php");
// Постраничная навигация
require_once(__DIR__."/Pagination.php");
// Градиент
require_once(__DIR__."/str2gradient.php"); 
// BB-коды
require_once(__DIR__."/bb.php");
// Обработка времени
require_once(__DIR__."/daytime.php");
// SimpleImage
require_once(__DIR__."/SimpleImage.php");
// Mobile Detect
require_once(__DIR__."/Mobile_Detect.php");
// Tools
require_once(__DIR__."/tools.php");
// IP посетителя
$ip = $_SERVER['REMOTE_ADDR'] ?? 'unknown';
// Определение реального браузера
$ua = $_SERVER['HTTP_USER_AGENT'] ?? 'unknown';
// Кодировка
mb_internal_encoding('UTF-8');
// Корневая папка
define('ROOT', 'http://'.$_SERVER['HTTP_HOST']);
// Все символы (REGEXP SQL)
define('RS_ALL_CHARS', '.*');
// Уровни пользователей
$levels = [

    'Пользователь',

    'Гл. администратор',

    'Журналист газеты',

    'Модератор форума',

    'Tester',

    'Администратор',

    'Модератор'

];
// Инфо о юзере
function user($user, $type = 0) {

    global $connect;

    if ($type == 1) {

        $sql = "select * from `users` where `login` = ?";

    } else {

        $sql = "select * from `users` where `id` = ?";

    }

    $result = $connect->prepare($sql);
    $result->execute(array($user));
    $info = $result->fetch(PDO::FETCH_LAZY);

    return $info;

}
// Инфо об авторизации юзера
function authlog($uid) {

    global $connect;

    if (user($uid)) {

        $result = $connect->prepare("select * from `authlog` where `uid` = ? order by `lasttime` desc");
        $result->execute(array($uid));
        $info = $result->fetch(PDO::FETCH_LAZY);

        return $info;

    } else
        return false;

}
// Статус онлайн
function online($uid) {

    $auth = authlog($uid);

    if ($auth && $auth['status'] == 1 && $auth['lasttime'] > time() - 300) {

        $online = deviceIcon($auth['ua']);

        return $online;

    } else
        return false;

}
// Иконка юзера (Путь)
function getUserIcon($uid) {

    $dir = $_SERVER['DOCUMENT_ROOT'].'/files/icon/';
    $mask = $uid . '_*';
    $files = glob($dir . $mask);

    return isset($files[0]) && is_readable($files[0]) && exif_imagetype($files[0]) ? $files[0] : false;

}
// Аватар юзера (Путь)
function getUserAvatar($uid) {

    $dir = $_SERVER['DOCUMENT_ROOT'].'/files/avatar/';
    $mask = $uid . '_*';
    $files = glob($dir . $mask);

    return isset($files[0]) && is_readable($files[0]) && exif_imagetype($files[0]) ? $files[0] : false;

}
// Градиент ника
function gradientUser($user) {

    $row = user($user, 1);

    if ($row && $row['color1'] && $row['color2']) {

        $login = str2gradient($row['login'], $row['color1'], $row['color2']);

        return $login;

    } else
        return $user;

}
// Иконка юзера
function iconUser($uid) {

    $row = user($uid);

    $icon = getUserIcon($uid);

    if (!$row) {

        $img = '<img src="/img/user/bot.png" alt="bot">';

    } elseif ($icon) {

       $img = '<img src="/files/icon/'.basename($icon).'" alt="icon">';

    } elseif ($row['ban'] > time()) {

        $img = '<img src="/img/user/ban.png" alt="ban">';

    } elseif ($row['admin'] == 0) {

        $img = $row['pol'] == 1 ? '<img src="/img/user/male.png" alt="male">' : '<img src="/img/user/female.png" alt="female">';

    } else {

        $img = $row['pol'] == 1 ? '<img src="/img/user/admin-male.png" alt="admin-male">' : '<img src="/img/user/admin-female.png" alt="admin-female">';

    }

    return $img;

}
// Ссылка на профиль
function profileLink($uid) {

    global $connect;

    $row = user($uid);

    if ($row) {

        /* Ссылка */

        $link = iconUser($row['id']) . '<a href="/user/'.$row['id'].'" class="mlink">'.gradientUser($row['login']).'</a>';

        /* Happy Birthsday */

        $birth = DateTime::createFromFormat('Y-m-d', $row['birth']);

        if ($birth && date('d.m') == $birth->format('d.m')) {

            $link .= '<img src="/img/cake.png" alt="cake">';

        }

    } else {

        $link = 'DELETED';

    }

    return $link;

}
// Приватная почта
function privateMail($from, $to) {

    global $connect;

    $count = $connect->prepare("select count(*) from `friend` where `status` = '1' and (`from` = :from and `to` = :to or `from` = :to and `to` = :from)");

    $row = user($from);

    if ($row) {

        if ($row['fmail'] == 1) {

            $result = 1;

        } else {

            $count->bindValue(':from', $from, PDO::PARAM_INT);
            $count->bindValue(':to', $to, PDO::PARAM_INT);
            $count->execute();

            $result = $count->fetchColumn();

        }

    }

    return $result ?? 0;

}
// Создаем уведомления
function notification($text, $user) {

    global $connect;

    if (user($user)) {

        $stmt = $connect->prepare("insert into `notifications` set `time` = ?, `uid` = ?, `text` = ?");

        return $stmt->execute(array(time(), $user, $text));

    } else
        return false;

}
// Зачисление средств
function pay($sum, $uid) {

    global $connect;

    if (user($uid) && is_numeric($sum)) {

        $pay = $connect->prepare("update  `users` set `money` = `money` + ? where `id` = ?");

        return $pay->execute(array($sum, $uid));

    } else
        return false;

}
// Добавляем в контакты
function contact_add($from, $to) {

    global $connect;

    if (user($from) && user($to)) {

        $count = $connect->prepare("select count(*) from `contacts` where `from` = :from and `to` = :to or `from` = :to and `to` = :from");
        $count->bindValue(':from', $from, PDO::PARAM_INT);
        $count->bindValue(':to', $to, PDO::PARAM_INT);
        $count->execute();

        if ($count->fetchColumn()) {

            $stmt = $connect->prepare("update `contacts` set `time` = :time where `from` = :from and `to` = :to or `from` = :to and `to` = :from");

            return $stmt->execute(array(':time' => time(), ':from' => $from, ':to' => $to));

        } else {

            $stmt = $connect->prepare("insert into `contacts` set `time` = ?, `from` = ?, `to` = ?");

            return $stmt->execute(array(time(), $from, $to));

        }

    } else
        return false;

}
// Очки дружбы
function friendPoint($from, $to, $col = 1) {

    global $connect;

    if (user($from) && user($to)) {

        $friend = $connect->prepare("select count(*) from `friend` where `status` = '1' and (`from` = :from and `to` = :to or `from` = :to and `to` = :from)");
        $friend->bindValue(':from', $from, PDO::PARAM_INT);
        $friend->bindValue(':to', $to, PDO::PARAM_INT);
        $friend->execute();

        if ($friend->fetchColumn()) {

            $point = $connect->prepare("update `friend` set `point` = `point` + :col where `from` = :from and `to` = :to or `from` = :to and `to` = :from");

            return $point->execute(array(':col' => $col, ':from' => $from, ':to' => $to));

        }

    } else
        return false;

}
// Рейтинг
function ratingUser($rating, $user) {

    global $connect;

    if (user($user)) {

        $stmt = $connect->prepare("update `users` set `rating` = `rating` + ? where `id` = ?");

        return $stmt->execute(array($rating, $user));

    } else
        return false;

}
// Звание
function rankUser($rating) {

    global $connect;

    $sql = $connect->query("select * from `rank` order by `rating` desc");

    foreach ($sql as $row) {

        if ($rating >= $row['rating']) {

            $rank = $row['rank'] . ' | ' . $rating;

            break;

        }

    }

    return $rank ?? $rating;

}
// Где юзер?
function whereUser($uid) {

    global $connect;

    $row = user($uid);

    if ($row) {

        $wid = isset($_GET['id']) ? intval($_GET['id']) : 0;

        if ($row['where'] != $_SERVER['PHP_SELF'] || $row['wid'] != $wid) {

            $stmt = $connect->prepare("update `users` set `where` = ?, `wid` = ? where `id` = ?");

            return $stmt->execute(array($_SERVER['PHP_SELF'], $wid, $uid));

        } else
            return true;

    } else
        return false;

}
// Скопление юзеров
function congestion($where, $wid = 0) {

    global $connect;

    $congestion = [];

    $data = $connect->prepare("select * from `users` where `where` = :where and `wid` = :wid order by `admin` desc, `rating` desc");
    $data->bindValue(':where', $where);
    $data->bindValue(':wid', $wid, PDO::PARAM_INT);
    $data->execute();
    $sql = $data->fetchAll();

    foreach ($sql as $row) {

        // Если онлайн, то добавляем в список
        if (online($row['id']))
            $congestion[] = $row['id'];

    }

    return $congestion;

}
// Вывод юзеров через запятую
function congestionOutputLinks($congestion, $limit = false) {

    $res = NULL;

    foreach ($congestion as $key => $uid) {

        $res .= profileLink($uid).', ';

        // Лимит
        if ($limit && $key >= $limit + 1)
            break;

    }

    $res = trim($res, ', ');

    if ($limit && count($congestion) > $limit)
        $res .= '...';

    return $res;

}
// Черный список
function in_blacklist($uid, $black) {

    global $connect;

    if (user($uid) && user($black)) {

        $black_r = $connect->prepare("select count(*) from `blacklist` where `uid` = ? and `black` = ?");
        $black_r->execute(array($uid, $black));

        return $black_r->fetchColumn();

    } else
        return false;

}
// Проверка браузера в серфинге
function is_forbid_browser($link) {

    global $ua, $connect;

    $data = $connect->prepare("select * from `forbid_browser` where `link` = :link order by `id` desc");
    $data->bindValue(':link', $link, PDO::PARAM_INT);
    $data->execute();
    $sql = $data->fetchAll();

    foreach ($sql as $row) {

        if ($row['browser'] != NULL && stristr($ua, $row['browser'])) {

            $result = 1;

            break;

        }

    }

    return $result ?? 0;

}
// Путь к файлу товара
function fileshop($id) {

    $dir = $_SERVER['DOCUMENT_ROOT'].'/files/shop/';
    $mask = $id . '_*';
    $fileshop = glob($dir . $mask);

    return isset($fileshop[0]) && is_readable($fileshop[0]) ? $fileshop[0] : false;

}

// Авторизация
if (isset($_COOKIE['user_id']) && isset($_COOKIE['pass']) && isset($_COOKIE['auth'])) {
    // проверяем авторизацию
    $authcheck = $connect->prepare("select count(*) from `authlog` where `status` = '1' and `uid` = ? and `id` = ?");
    $authcheck->execute(array($_COOKIE['user_id'], $_COOKIE['auth']));
    // ищем юзера в базе
    $user = user($_COOKIE['user_id']);
    if ($user && $user['pass'] == $_COOKIE['pass'] && $authcheck->fetchColumn()) {
        // Юзер авторизован
        $active = 1;
        // Онлайн
        $authup = $connect->prepare("update `authlog` set `lasttime` = ? where `id` = ?");
        $authup->execute(array(time(), $_COOKIE['auth']));
        // Где юзер?
        whereUser($user['id']);
        // Инфо об авторизации
        $user_auth = authlog($user['id']);
    } else {
        // Удаляем на всякий случай :)
        unset($user);
        // сбрасываем куки
        setcookie('user_id', null, time() - 3600, '/');
        setcookie('pass', null, time() - 3600, '/');
        setcookie('auth', null, time() - 3600, '/');
    }
}

// Временная зона
$timezone = empty($user['timezone']) ? $sys['system']['timezone'] : $user['timezone'];
if (isAvailableTimezone($timezone))
    date_default_timezone_set($timezone);

// админ
$adm_id = $user['admin'] ?? false;

// Счетчики и т. п.
require(__DIR__."/counters.php");